/****************************************************************************
** Meta object code from reading C++ file 'session2interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/global_util/dbus/session2interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session2interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeAuthenticate1SessionInterface::qt_create_metaobjectdata<qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeAuthenticate1SessionInterface",
        "Status",
        "",
        "flag",
        "status",
        "msg",
        "FactorsInfoChanged",
        "MFAInfoList",
        "value",
        "IsFuzzyMFAChanged",
        "IsMFAChanged",
        "PINLenChanged",
        "PromptChanged",
        "UsernameChanged",
        "EncryptKey",
        "QDBusPendingReply<int,ArrayInt,QString>",
        "encryptType",
        "ArrayInt",
        "encryptMethod",
        "QDBusReply<int>",
        "ArrayInt&",
        "encryptMethod_",
        "QString&",
        "publicKey",
        "End",
        "QDBusPendingReply<int>",
        "GetResult",
        "PrivilegesDisable",
        "QDBusPendingReply<>",
        "PrivilegesDisableQueued",
        "PrivilegesEnable",
        "QDBusPendingReply<bool>",
        "path",
        "Quit",
        "QuitQueued",
        "SetQuitFlag",
        "SetQuitFlagQueued",
        "SetSymmetricKey",
        "key",
        "SetSymmetricKeyQueued",
        "SetToken",
        "token",
        "SetTokenQueued",
        "Start",
        "timeout",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "FactorsInfo",
        "IsFuzzyMFA",
        "IsMFA",
        "PINLen",
        "Prompt",
        "Username"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Status'
        QtMocHelpers::SignalData<void(int, int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'FactorsInfoChanged'
        QtMocHelpers::SignalData<void(MFAInfoList) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'IsFuzzyMFAChanged'
        QtMocHelpers::SignalData<void(bool) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'IsMFAChanged'
        QtMocHelpers::SignalData<void(bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'PINLenChanged'
        QtMocHelpers::SignalData<void(int) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'PromptChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'UsernameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'EncryptKey'
        QtMocHelpers::SlotData<QDBusPendingReply<int,ArrayInt,QString>(int, ArrayInt)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'EncryptKey'
        QtMocHelpers::SlotData<QDBusReply<int>(int, ArrayInt, ArrayInt &, QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'End'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'GetResult'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(26, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'PrivilegesDisable'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(27, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'PrivilegesDisableQueued'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PrivilegesEnable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(30, 2, QMC::AccessPublic, 0x80000000 | 31, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'Quit'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(33, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'QuitQueued'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetQuitFlag'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(35, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'SetQuitFlagQueued'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'SetSymmetricKey'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QByteArray &)>(37, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QByteArray, 38 },
        }}),
        // Slot 'SetSymmetricKeyQueued'
        QtMocHelpers::SlotData<void(const QByteArray &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 38 },
        }}),
        // Slot 'SetToken'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QByteArray &)>(40, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::Int, 3 }, { QMetaType::QByteArray, 41 },
        }}),
        // Slot 'SetTokenQueued'
        QtMocHelpers::SlotData<void(int, const QByteArray &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QByteArray, 41 },
        }}),
        // Slot 'Start'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, int)>(43, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 44 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 53 }, { 0x80000000 | 54, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'FactorsInfo'
        QtMocHelpers::PropertyData<MFAInfoList>(55, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'IsFuzzyMFA'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'IsMFA'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'PINLen'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'Prompt'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'Username'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeAuthenticate1SessionInterface, qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeAuthenticate1SessionInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeAuthenticate1SessionInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeAuthenticate1SessionInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->FactorsInfoChanged((*reinterpret_cast<std::add_pointer_t<MFAInfoList>>(_a[1]))); break;
        case 2: _t->IsFuzzyMFAChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->IsMFAChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->PINLenChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->PromptChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->UsernameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: { QDBusPendingReply<int,ArrayInt,QString> _r = _t->EncryptKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ArrayInt>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int,ArrayInt,QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusReply<int> _r = _t->EncryptKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ArrayInt>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ArrayInt&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<int> _r = _t->End((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<int> _r = _t->GetResult();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->PrivilegesDisable();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->PrivilegesDisableQueued(); break;
        case 13: { QDBusPendingReply<bool> _r = _t->PrivilegesEnable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->Quit();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->QuitQueued(); break;
        case 16: { QDBusPendingReply<> _r = _t->SetQuitFlag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->SetQuitFlagQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: { QDBusPendingReply<> _r = _t->SetSymmetricKey((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->SetSymmetricKeyQueued((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 20: { QDBusPendingReply<> _r = _t->SetToken((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->SetTokenQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 22: { QDBusPendingReply<int> _r = _t->Start((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 24: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 25: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MFAInfoList >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ArrayInt >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ArrayInt >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(int , int , const QString & )>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::Status, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(MFAInfoList ) const>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::FactorsInfoChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(bool ) const>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::IsFuzzyMFAChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(bool ) const>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::IsMFAChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(int ) const>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::PINLenChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::PromptChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAuthenticate1SessionInterface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAuthenticate1SessionInterface::UsernameChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MFAInfoList >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MFAInfoList*>(_v) = _t->factorsInfo(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isFuzzyMFA(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isMFA(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->pINLen(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->prompt(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeAuthenticate1SessionInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeAuthenticate1SessionInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN43__OrgDeepinDdeAuthenticate1SessionInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeAuthenticate1SessionInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeAuthenticate1SessionInterface::Status(int _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void __OrgDeepinDdeAuthenticate1SessionInterface::FactorsInfoChanged(MFAInfoList _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAuthenticate1SessionInterface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeAuthenticate1SessionInterface::IsFuzzyMFAChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAuthenticate1SessionInterface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeAuthenticate1SessionInterface::IsMFAChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAuthenticate1SessionInterface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeAuthenticate1SessionInterface::PINLenChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAuthenticate1SessionInterface *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeAuthenticate1SessionInterface::PromptChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAuthenticate1SessionInterface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeAuthenticate1SessionInterface::UsernameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAuthenticate1SessionInterface *>(this), &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
