// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include <QtCore/QString>
#include <QtCore/QFile>
#include <QtWidgets/QWidget>

#ifndef GLOBAL_GLOBA_H_
#define GLOBAL_GLOBAL_H_

void updateStyle(QString styleFiles, QWidget* widget);

#endif  // GLOBAL_GLOBAL_H_
