/****************************************************************************
** Meta object code from reading C++ file 'greeterworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lightdm-deepin-greeter/greeterworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'greeterworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13GreeterWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto GreeterWorker::qt_create_metaobjectdata<qt_meta_tag_ZN13GreeterWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GreeterWorker",
        "requestUpdateBackground",
        "",
        "path",
        "requestShowPrompt",
        "prompt",
        "requestShowMessage",
        "message",
        "requestShowUsersWithTheSameName",
        "nativeUserName",
        "doMainAccountDetail",
        "createAuthentication",
        "account",
        "destroyAuthentication",
        "startAuthentication",
        "AuthFlags",
        "authType",
        "endAuthentication",
        "sendTokenToAuth",
        "AuthType",
        "token",
        "checkAccount",
        "switchUser",
        "checkSameNameAccount",
        "restartResetSessionTimer",
        "onAuthFinished",
        "onNoPasswordLoginChanged",
        "noPassword",
        "onAuthStateChanged",
        "type",
        "state",
        "onReceiptChanged",
        "onCurrentUserChanged",
        "std::shared_ptr<User>",
        "user",
        "onSessionCreated",
        "terminalLockedChanged",
        "QDBusMessage",
        "msg",
        "resetAuth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestUpdateBackground'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'requestShowPrompt'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'requestShowMessage'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'requestShowUsersWithTheSameName'
        QtMocHelpers::SignalData<void(const QString, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'createAuthentication'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'destroyAuthentication'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'startAuthentication'
        QtMocHelpers::SlotData<void(const QString &, const AuthFlags)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'endAuthentication'
        QtMocHelpers::SlotData<void(const QString &, const AuthFlags)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'sendTokenToAuth'
        QtMocHelpers::SlotData<void(const QString &, const AuthType, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 19, 16 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'checkAccount'
        QtMocHelpers::SlotData<void(const QString &, bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'checkSameNameAccount'
        QtMocHelpers::SlotData<void(const QString &, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'restartResetSessionTimer'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAuthFinished'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onNoPasswordLoginChanged'
        QtMocHelpers::SlotData<void(const QString &, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Bool, 27 },
        }}),
        // Slot 'onAuthStateChanged'
        QtMocHelpers::SlotData<void(const int, const int, const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 30 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'onReceiptChanged'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'onCurrentUserChanged'
        QtMocHelpers::SlotData<void(const std::shared_ptr<User> &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'onSessionCreated'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'terminalLockedChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'resetAuth'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GreeterWorker, qt_meta_tag_ZN13GreeterWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GreeterWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<Auth::AuthInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13GreeterWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13GreeterWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13GreeterWorkerE_t>.metaTypes,
    nullptr
} };

void GreeterWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GreeterWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestUpdateBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->requestShowPrompt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->requestShowMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->requestShowUsersWithTheSameName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->createAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->destroyAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->startAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 7: _t->endAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 8: _t->sendTokenToAuth((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->checkAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->checkSameNameAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->restartResetSessionTimer(); break;
        case 12: _t->onAuthFinished(); break;
        case 13: _t->onNoPasswordLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->onAuthStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->onReceiptChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->onCurrentUserChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<User>>>(_a[1]))); break;
        case 17: _t->onSessionCreated(); break;
        case 18: _t->terminalLockedChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 19: _t->resetAuth((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GreeterWorker::*)(const QString & )>(_a, &GreeterWorker::requestUpdateBackground, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GreeterWorker::*)(const QString & )>(_a, &GreeterWorker::requestShowPrompt, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GreeterWorker::*)(const QString & )>(_a, &GreeterWorker::requestShowMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GreeterWorker::*)(const QString , const QString & )>(_a, &GreeterWorker::requestShowUsersWithTheSameName, 3))
            return;
    }
}

const QMetaObject *GreeterWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GreeterWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13GreeterWorkerE_t>.strings))
        return static_cast<void*>(this);
    return Auth::AuthInterface::qt_metacast(_clname);
}

int GreeterWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Auth::AuthInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void GreeterWorker::requestUpdateBackground(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void GreeterWorker::requestShowPrompt(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void GreeterWorker::requestShowMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void GreeterWorker::requestShowUsersWithTheSameName(const QString _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
