/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Authenticate1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef AUTHENTICATE_INTERFACE_H
#define AUTHENTICATE_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.deepin.dde.Authenticate1
 */
class AuthenticateInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Authenticate1"; }

public:
    AuthenticateInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~AuthenticateInterface();

    Q_PROPERTY(int FrameworkState READ frameworkState)
    inline int frameworkState() const
    { return qvariant_cast< int >(property("FrameworkState")); }

    Q_PROPERTY(QString SupportEncrypts READ supportEncrypts)
    inline QString supportEncrypts() const
    { return qvariant_cast< QString >(property("SupportEncrypts")); }

    Q_PROPERTY(int SupportedFlags READ supportedFlags)
    inline int supportedFlags() const
    { return qvariant_cast< int >(property("SupportedFlags")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> Authenticate(const QString &username, int authFlags, int appType)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(username) << QVariant::fromValue(authFlags) << QVariant::fromValue(appType);
        return asyncCallWithArgumentList(QStringLiteral("Authenticate"), argumentList);
    }

    inline QDBusPendingReply<QString> GetLimits(const QString &username)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(username);
        return asyncCallWithArgumentList(QStringLiteral("GetLimits"), argumentList);
    }

    inline QDBusPendingReply<QString> PreOneKeyLogin(int flag)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(flag);
        return asyncCallWithArgumentList(QStringLiteral("PreOneKeyLogin"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void LimitUpdated(const QString &in0);
};

#endif
