/****************************************************************************
** Meta object code from reading C++ file 'lockcontent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/session-widgets/lockcontent.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lockcontent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11LockContentE_t {};
} // unnamed namespace

template <> constexpr inline auto LockContent::qt_create_metaobjectdata<qt_meta_tag_ZN11LockContentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LockContent",
        "requestBackground",
        "",
        "path",
        "requestSwitchToUser",
        "std::shared_ptr<User>",
        "user",
        "requestSetLayout",
        "value",
        "unlockActionFinish",
        "requestStartAuthentication",
        "account",
        "AuthFlags",
        "authType",
        "sendTokenToAuth",
        "AuthType",
        "token",
        "requestEndAuthentication",
        "authFinished",
        "requestCheckSameNameAccount",
        "switchUser",
        "requestCheckAccount",
        "requestLockFrameHide",
        "parentChanged",
        "noPasswordLoginChanged",
        "noPassword",
        "pushPasswordFrame",
        "pushUserFrame",
        "pushConfirmFrame",
        "pushShutdownFrame",
        "setMPRISEnable",
        "state",
        "onNewConnection",
        "onDisConnect",
        "showUserList",
        "showLockScreen",
        "showShutdown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestBackground'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'requestSwitchToUser'
        QtMocHelpers::SignalData<void(std::shared_ptr<User>)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'requestSetLayout'
        QtMocHelpers::SignalData<void(std::shared_ptr<User>, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'unlockActionFinish'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestStartAuthentication'
        QtMocHelpers::SignalData<void(const QString &, const AuthFlags)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'sendTokenToAuth'
        QtMocHelpers::SignalData<void(const QString &, const AuthType, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 15, 13 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'requestEndAuthentication'
        QtMocHelpers::SignalData<void(const QString &, const AuthFlags)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'authFinished'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestCheckSameNameAccount'
        QtMocHelpers::SignalData<void(const QString &, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Bool, 20 },
        }}),
        // Signal 'requestCheckAccount'
        QtMocHelpers::SignalData<void(const QString &, bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Bool, 20 },
        }}),
        // Signal 'requestLockFrameHide'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parentChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noPasswordLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'pushPasswordFrame'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pushUserFrame'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pushConfirmFrame'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pushShutdownFrame'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMPRISEnable'
        QtMocHelpers::SlotData<void(const bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'onNewConnection'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDisConnect'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showUserList'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showLockScreen'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showShutdown'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LockContent, qt_meta_tag_ZN11LockContentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LockContent::staticMetaObject = { {
    QMetaObject::SuperData::link<SessionBaseWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LockContentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LockContentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11LockContentE_t>.metaTypes,
    nullptr
} };

void LockContent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LockContent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->requestSwitchToUser((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<User>>>(_a[1]))); break;
        case 2: _t->requestSetLayout((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<User>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->unlockActionFinish(); break;
        case 4: _t->requestStartAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 5: _t->sendTokenToAuth((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->requestEndAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 7: _t->authFinished(); break;
        case 8: _t->requestCheckSameNameAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->requestCheckAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->requestLockFrameHide(); break;
        case 11: _t->parentChanged(); break;
        case 12: _t->noPasswordLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->pushPasswordFrame(); break;
        case 14: _t->pushUserFrame(); break;
        case 15: _t->pushConfirmFrame(); break;
        case 16: _t->pushShutdownFrame(); break;
        case 17: _t->setMPRISEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->onNewConnection(); break;
        case 19: _t->onDisConnect(); break;
        case 20: _t->showUserList(); break;
        case 21: _t->showLockScreen(); break;
        case 22: _t->showShutdown(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & )>(_a, &LockContent::requestBackground, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(std::shared_ptr<User> )>(_a, &LockContent::requestSwitchToUser, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(std::shared_ptr<User> , const QString & )>(_a, &LockContent::requestSetLayout, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)()>(_a, &LockContent::unlockActionFinish, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & , const AuthFlags )>(_a, &LockContent::requestStartAuthentication, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & , const AuthType , const QString & )>(_a, &LockContent::sendTokenToAuth, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & , const AuthFlags )>(_a, &LockContent::requestEndAuthentication, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)()>(_a, &LockContent::authFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & , bool )>(_a, &LockContent::requestCheckSameNameAccount, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & , bool )>(_a, &LockContent::requestCheckAccount, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)()>(_a, &LockContent::requestLockFrameHide, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)()>(_a, &LockContent::parentChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (LockContent::*)(const QString & , bool )>(_a, &LockContent::noPasswordLoginChanged, 12))
            return;
    }
}

const QMetaObject *LockContent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LockContent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LockContentE_t>.strings))
        return static_cast<void*>(this);
    return SessionBaseWindow::qt_metacast(_clname);
}

int LockContent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SessionBaseWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void LockContent::requestBackground(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LockContent::requestSwitchToUser(std::shared_ptr<User> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void LockContent::requestSetLayout(std::shared_ptr<User> _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void LockContent::unlockActionFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LockContent::requestStartAuthentication(const QString & _t1, const AuthFlags _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void LockContent::sendTokenToAuth(const QString & _t1, const AuthType _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void LockContent::requestEndAuthentication(const QString & _t1, const AuthFlags _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void LockContent::authFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void LockContent::requestCheckSameNameAccount(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void LockContent::requestCheckAccount(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void LockContent::requestLockFrameHide()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void LockContent::parentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void LockContent::noPasswordLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}
QT_WARNING_POP
