/****************************************************************************
** Meta object code from reading C++ file 'authcommon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libdde-auth/authcommon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'authcommon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10AuthCommonE_t {};
} // unnamed namespace

template <> constexpr inline auto AuthCommon::qt_create_metaobjectdata<qt_meta_tag_ZN10AuthCommonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AuthCommon",
        "AuthFlags",
        "AuthType",
        "AT_None",
        "AT_Password",
        "AT_Fingerprint",
        "AT_Face",
        "AT_ActiveDirectory",
        "AT_Ukey",
        "AT_FingerVein",
        "AT_Iris",
        "AT_Passkey",
        "AT_PAM",
        "AT_Custom",
        "AT_All",
        "AuthState",
        "AS_None",
        "AS_Success",
        "AS_Failure",
        "AS_Cancel",
        "AS_Timeout",
        "AS_Error",
        "AS_Verify",
        "AS_Exception",
        "AS_Prompt",
        "AS_Started",
        "AS_Ended",
        "AS_Locked",
        "AS_Recover",
        "AS_Unlocked"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'AuthFlags'
        QtMocHelpers::EnumData<AuthFlags>(1, 2, QMC::EnumIsFlag).add({
            {    3, AuthType::AT_None },
            {    4, AuthType::AT_Password },
            {    5, AuthType::AT_Fingerprint },
            {    6, AuthType::AT_Face },
            {    7, AuthType::AT_ActiveDirectory },
            {    8, AuthType::AT_Ukey },
            {    9, AuthType::AT_FingerVein },
            {   10, AuthType::AT_Iris },
            {   11, AuthType::AT_Passkey },
            {   12, AuthType::AT_PAM },
            {   13, AuthType::AT_Custom },
            {   14, AuthType::AT_All },
        }),
        // enum 'AuthState'
        QtMocHelpers::EnumData<AuthState>(15, 15, QMC::EnumFlags{}).add({
            {   16, AuthState::AS_None },
            {   17, AuthState::AS_Success },
            {   18, AuthState::AS_Failure },
            {   19, AuthState::AS_Cancel },
            {   20, AuthState::AS_Timeout },
            {   21, AuthState::AS_Error },
            {   22, AuthState::AS_Verify },
            {   23, AuthState::AS_Exception },
            {   24, AuthState::AS_Prompt },
            {   25, AuthState::AS_Started },
            {   26, AuthState::AS_Ended },
            {   27, AuthState::AS_Locked },
            {   28, AuthState::AS_Recover },
            {   29, AuthState::AS_Unlocked },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10AuthCommonE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN10AuthCommonE =
    AuthCommon::qt_create_metaobjectdata<qt_meta_tag_ZN10AuthCommonE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10AuthCommonE =
    qt_staticMetaObjectContent_ZN10AuthCommonE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10AuthCommonE =
    qt_staticMetaObjectContent_ZN10AuthCommonE.relocatingData;

Q_CONSTINIT const QMetaObject AuthCommon::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10AuthCommonE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10AuthCommonE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10AuthCommonE.metaTypes,
    nullptr
} };

QT_WARNING_POP
