/****************************************************************************
** Meta object code from reading C++ file 'selfinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/global_util/dbus/selfinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'selfinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgFreedesktopLogin1SessionInterface::qt_create_metaobjectdata<qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgFreedesktopLogin1SessionInterface",
        "ActiveChanged",
        "",
        "value",
        "DesktopChanged",
        "DisplayChanged",
        "IdChanged",
        "NameChanged",
        "Activate",
        "QDBusPendingReply<>",
        "ActivateQueued",
        "Lock",
        "LockQueued",
        "Terminate",
        "TerminateQueued",
        "Unlock",
        "UnlockQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Active",
        "Desktop",
        "Display",
        "Id",
        "Name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActiveChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'DesktopChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'DisplayChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'IdChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'Activate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'ActivateQueued'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Lock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(11, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'LockQueued'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Terminate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'TerminateQueued'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Unlock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'UnlockQueued'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { 0x80000000 | 26, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Active'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'Desktop'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'Display'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'Id'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgFreedesktopLogin1SessionInterface, qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgFreedesktopLogin1SessionInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgFreedesktopLogin1SessionInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgFreedesktopLogin1SessionInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->DesktopChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->DisplayChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->IdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QDBusPendingReply<> _r = _t->Activate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->ActivateQueued(); break;
        case 7: { QDBusPendingReply<> _r = _t->Lock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->LockQueued(); break;
        case 9: { QDBusPendingReply<> _r = _t->Terminate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->TerminateQueued(); break;
        case 11: { QDBusPendingReply<> _r = _t->Unlock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->UnlockQueued(); break;
        case 13: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 14: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 15: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgFreedesktopLogin1SessionInterface::*)(bool ) const>(_a, &__OrgFreedesktopLogin1SessionInterface::ActiveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgFreedesktopLogin1SessionInterface::*)(const QString & ) const>(_a, &__OrgFreedesktopLogin1SessionInterface::DesktopChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgFreedesktopLogin1SessionInterface::*)(const QString & ) const>(_a, &__OrgFreedesktopLogin1SessionInterface::DisplayChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgFreedesktopLogin1SessionInterface::*)(const QString & ) const>(_a, &__OrgFreedesktopLogin1SessionInterface::IdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgFreedesktopLogin1SessionInterface::*)(const QString & ) const>(_a, &__OrgFreedesktopLogin1SessionInterface::NameChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->desktop(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->display(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgFreedesktopLogin1SessionInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgFreedesktopLogin1SessionInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38__OrgFreedesktopLogin1SessionInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgFreedesktopLogin1SessionInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void __OrgFreedesktopLogin1SessionInterface::ActiveChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgFreedesktopLogin1SessionInterface *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgFreedesktopLogin1SessionInterface::DesktopChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgFreedesktopLogin1SessionInterface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgFreedesktopLogin1SessionInterface::DisplayChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgFreedesktopLogin1SessionInterface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgFreedesktopLogin1SessionInterface::IdChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgFreedesktopLogin1SessionInterface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgFreedesktopLogin1SessionInterface::NameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgFreedesktopLogin1SessionInterface *>(this), &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
