/****************************************************************************
** Meta object code from reading C++ file 'userinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/session-widgets/userinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'userinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4UserE_t {};
} // unnamed namespace

template <> constexpr inline auto User::qt_create_metaobjectdata<qt_meta_tag_ZN4UserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "User",
        "avatarChanged",
        "",
        "autoLoginStateChanged",
        "desktopBackgroundChanged",
        "displayNameChanged",
        "greeterBackgroundChanged",
        "keyboardLayoutChanged",
        "keyboardLayoutListChanged",
        "limitsInfoChanged",
        "const QMap<int,LimitsInfo>*",
        "localeChanged",
        "locale",
        "loginStateChanged",
        "noPasswordLoginChanged",
        "passwordHintChanged",
        "shortDateFormatChanged",
        "shortTimeFormatChanged",
        "weekdayFormatChanged",
        "use24HourFormatChanged",
        "passwordExpiredInfoChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'avatarChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'autoLoginStateChanged'
        QtMocHelpers::SignalData<void(const bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'desktopBackgroundChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'displayNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'greeterBackgroundChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'keyboardLayoutChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'keyboardLayoutListChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Signal 'limitsInfoChanged'
        QtMocHelpers::SignalData<void(const QMap<int,LimitsInfo> *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'localeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'loginStateChanged'
        QtMocHelpers::SignalData<void(const bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'noPasswordLoginChanged'
        QtMocHelpers::SignalData<void(const bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'passwordHintChanged'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'shortDateFormatChanged'
        QtMocHelpers::SignalData<void(const int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'shortTimeFormatChanged'
        QtMocHelpers::SignalData<void(const int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'weekdayFormatChanged'
        QtMocHelpers::SignalData<void(const int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'use24HourFormatChanged'
        QtMocHelpers::SignalData<void(const bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'passwordExpiredInfoChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<User, qt_meta_tag_ZN4UserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject User::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4UserE_t>.metaTypes,
    nullptr
} };

void User::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<User *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->avatarChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->autoLoginStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->desktopBackgroundChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->displayNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->greeterBackgroundChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->keyboardLayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->keyboardLayoutListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->limitsInfoChanged((*reinterpret_cast<std::add_pointer_t<const QMap<int,LimitsInfo>*>>(_a[1]))); break;
        case 8: _t->localeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->loginStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->noPasswordLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->passwordHintChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->shortDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->shortTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->weekdayFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->use24HourFormatChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->passwordExpiredInfoChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::avatarChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool )>(_a, &User::autoLoginStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::desktopBackgroundChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::displayNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::greeterBackgroundChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::keyboardLayoutChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QStringList & )>(_a, &User::keyboardLayoutListChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QMap<int,LimitsInfo> * )>(_a, &User::limitsInfoChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::localeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool )>(_a, &User::loginStateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool )>(_a, &User::noPasswordLoginChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::passwordHintChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const int )>(_a, &User::shortDateFormatChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const int )>(_a, &User::shortTimeFormatChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const int )>(_a, &User::weekdayFormatChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool )>(_a, &User::use24HourFormatChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::passwordExpiredInfoChanged, 16))
            return;
    }
}

const QMetaObject *User::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *User::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int User::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void User::avatarChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void User::autoLoginStateChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void User::desktopBackgroundChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void User::displayNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void User::greeterBackgroundChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void User::keyboardLayoutChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void User::keyboardLayoutListChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void User::limitsInfoChanged(const QMap<int,LimitsInfo> * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void User::localeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void User::loginStateChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void User::noPasswordLoginChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void User::passwordHintChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void User::shortDateFormatChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void User::shortTimeFormatChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void User::weekdayFormatChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void User::use24HourFormatChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void User::passwordExpiredInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
namespace {
struct qt_meta_tag_ZN10NativeUserE_t {};
} // unnamed namespace

template <> constexpr inline auto NativeUser::qt_create_metaobjectdata<qt_meta_tag_ZN10NativeUserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NativeUser",
        "updateAvatar",
        "",
        "path",
        "updateAutomaticLogin",
        "autoLoginState",
        "updateDesktopBackgrounds",
        "backgrounds",
        "updateFullName",
        "fullName",
        "updateGreeterBackground",
        "updateKeyboardLayout",
        "keyboardLayout",
        "updateKeyboardLayoutList",
        "keyboardLayoutList",
        "updateLocale",
        "locale",
        "updateName",
        "name",
        "updateNoPasswordLogin",
        "isNoPasswordLogin",
        "updatePasswordHint",
        "hint",
        "updatePasswordState",
        "state",
        "updateShortDateFormat",
        "format",
        "updateShortTimeFormat",
        "updateWeekdayFormat",
        "updateUid",
        "uid",
        "updateUse24HourFormat",
        "is24HourFormat",
        "updateAccountType"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateAvatar'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'updateAutomaticLogin'
        QtMocHelpers::SlotData<void(const bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'updateDesktopBackgrounds'
        QtMocHelpers::SlotData<void(const QStringList &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'updateFullName'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'updateGreeterBackground'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'updateKeyboardLayout'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'updateKeyboardLayoutList'
        QtMocHelpers::SlotData<void(const QStringList &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Slot 'updateLocale'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'updateName'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'updateNoPasswordLogin'
        QtMocHelpers::SlotData<void(const bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'updatePasswordHint'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'updatePasswordState'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'updateShortDateFormat'
        QtMocHelpers::SlotData<void(const int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'updateShortTimeFormat'
        QtMocHelpers::SlotData<void(const int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'updateWeekdayFormat'
        QtMocHelpers::SlotData<void(const int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'updateUid'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'updateUse24HourFormat'
        QtMocHelpers::SlotData<void(const bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'updateAccountType'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NativeUser, qt_meta_tag_ZN10NativeUserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NativeUser::staticMetaObject = { {
    QMetaObject::SuperData::link<User::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10NativeUserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10NativeUserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10NativeUserE_t>.metaTypes,
    nullptr
} };

void NativeUser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NativeUser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateAvatar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->updateAutomaticLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->updateDesktopBackgrounds((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->updateFullName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->updateGreeterBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->updateKeyboardLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->updateKeyboardLayoutList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->updateLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->updateName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->updateNoPasswordLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->updatePasswordHint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->updatePasswordState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->updateShortDateFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->updateShortTimeFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->updateWeekdayFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->updateUid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->updateUse24HourFormat((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->updateAccountType(); break;
        default: ;
        }
    }
}

const QMetaObject *NativeUser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NativeUser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10NativeUserE_t>.strings))
        return static_cast<void*>(this);
    return User::qt_metacast(_clname);
}

int NativeUser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = User::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN12ADDomainUserE_t {};
} // unnamed namespace

template <> constexpr inline auto ADDomainUser::qt_create_metaobjectdata<qt_meta_tag_ZN12ADDomainUserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ADDomainUser"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ADDomainUser, qt_meta_tag_ZN12ADDomainUserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ADDomainUser::staticMetaObject = { {
    QMetaObject::SuperData::link<User::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ADDomainUserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ADDomainUserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ADDomainUserE_t>.metaTypes,
    nullptr
} };

void ADDomainUser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ADDomainUser *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ADDomainUser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ADDomainUser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ADDomainUserE_t>.strings))
        return static_cast<void*>(this);
    return User::qt_metacast(_clname);
}

int ADDomainUser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = User::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
