/****************************************************************************
** Meta object code from reading C++ file 'lockworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dde-lock/lockworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lockworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10LockWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto LockWorker::qt_create_metaobjectdata<qt_meta_tag_ZN10LockWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LockWorker",
        "createAuthentication",
        "",
        "account",
        "destroyAuthentication",
        "startAuthentication",
        "AuthFlags",
        "authType",
        "endAuthentication",
        "sendTokenToAuth",
        "AuthType",
        "token",
        "onEndAuthentication",
        "switchToUser",
        "std::shared_ptr<User>",
        "user",
        "restartResetSessionTimer",
        "onAuthFinished",
        "onAuthStateChanged",
        "type",
        "state",
        "message",
        "disableGlobalShortcutsForWayland",
        "enable",
        "checkAccount",
        "switchUser",
        "authFinishedAction",
        "onNoPasswordLoginChanged",
        "noPassword"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createAuthentication'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'destroyAuthentication'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'startAuthentication'
        QtMocHelpers::SlotData<void(const QString &, const AuthFlags)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'endAuthentication'
        QtMocHelpers::SlotData<void(const QString &, const AuthFlags)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'sendTokenToAuth'
        QtMocHelpers::SlotData<void(const QString &, const AuthType, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 10, 7 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'onEndAuthentication'
        QtMocHelpers::SlotData<void(const QString &, const AuthFlags)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'switchToUser'
        QtMocHelpers::SlotData<void(std::shared_ptr<User>)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'restartResetSessionTimer'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAuthFinished'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAuthStateChanged'
        QtMocHelpers::SlotData<void(const int, const int, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'disableGlobalShortcutsForWayland'
        QtMocHelpers::SlotData<void(const bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'checkAccount'
        QtMocHelpers::SlotData<void(const QString &, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'authFinishedAction'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onNoPasswordLoginChanged'
        QtMocHelpers::SlotData<void(const QString &, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LockWorker, qt_meta_tag_ZN10LockWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LockWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<Auth::AuthInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LockWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LockWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10LockWorkerE_t>.metaTypes,
    nullptr
} };

void LockWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LockWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->destroyAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->startAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 3: _t->endAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 4: _t->sendTokenToAuth((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->onEndAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AuthFlags>>(_a[2]))); break;
        case 6: _t->switchToUser((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<User>>>(_a[1]))); break;
        case 7: _t->restartResetSessionTimer(); break;
        case 8: _t->onAuthFinished(); break;
        case 9: _t->onAuthStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->disableGlobalShortcutsForWayland((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->checkAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->authFinishedAction(); break;
        case 13: _t->onNoPasswordLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *LockWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LockWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LockWorkerE_t>.strings))
        return static_cast<void*>(this);
    return Auth::AuthInterface::qt_metacast(_clname);
}

int LockWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Auth::AuthInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
