/****************************************************************************
** Meta object code from reading C++ file 'controlwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/widgets/controlwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'controlwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14FloatingButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto FloatingButton::qt_create_metaobjectdata<qt_meta_tag_ZN14FloatingButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FloatingButton",
        "requestShowMenu",
        "",
        "requestShowTips",
        "requestHideTips",
        "buttonHide"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestShowMenu'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestShowTips'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestHideTips'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'buttonHide'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FloatingButton, qt_meta_tag_ZN14FloatingButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FloatingButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DFloatingButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14FloatingButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14FloatingButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14FloatingButtonE_t>.metaTypes,
    nullptr
} };

void FloatingButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FloatingButton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestShowMenu(); break;
        case 1: _t->requestShowTips(); break;
        case 2: _t->requestHideTips(); break;
        case 3: _t->buttonHide(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FloatingButton::*)()>(_a, &FloatingButton::requestShowMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FloatingButton::*)()>(_a, &FloatingButton::requestShowTips, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FloatingButton::*)()>(_a, &FloatingButton::requestHideTips, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FloatingButton::*)()>(_a, &FloatingButton::buttonHide, 3))
            return;
    }
}

const QMetaObject *FloatingButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FloatingButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14FloatingButtonE_t>.strings))
        return static_cast<void*>(this);
    return DFloatingButton::qt_metacast(_clname);
}

int FloatingButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFloatingButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void FloatingButton::requestShowMenu()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FloatingButton::requestShowTips()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FloatingButton::requestHideTips()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FloatingButton::buttonHide()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN13ControlWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ControlWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13ControlWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ControlWidget",
        "requestSwitchUser",
        "",
        "requestShutdown",
        "requestSwitchSession",
        "requestSwitchVirtualKB",
        "requestKeyboardLayout",
        "QPoint",
        "pos",
        "requestShowModule",
        "name",
        "callShowForce",
        "requestShowTrayModule",
        "QWidget*",
        "trayWidget",
        "contentWidget",
        "notifyKeyboardLayoutHidden",
        "addModule",
        "TrayPlugin*",
        "module",
        "removeModule",
        "setVirtualKBVisible",
        "visible",
        "setUserSwitchEnable",
        "setSessionSwitchEnable",
        "chooseToSession",
        "session",
        "leftKeySwitch",
        "rightKeySwitch",
        "setKBLayoutVisible",
        "setKeyboardType",
        "str",
        "setKeyboardList",
        "onItemClicked",
        "updateModuleVisible",
        "setCanShowMenu",
        "state",
        "updatePluginVisible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestSwitchUser'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestShutdown'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSwitchSession'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSwitchVirtualKB'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestKeyboardLayout'
        QtMocHelpers::SignalData<void(const QPoint &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'requestShowModule'
        QtMocHelpers::SignalData<void(const QString &, const bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestShowModule'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'requestShowTrayModule'
        QtMocHelpers::SignalData<void(QWidget *, QWidget *, const bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestShowTrayModule'
        QtMocHelpers::SignalData<void(QWidget *, QWidget *)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
        }}),
        // Signal 'notifyKeyboardLayoutHidden'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addModule'
        QtMocHelpers::SlotData<void(TrayPlugin *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'removeModule'
        QtMocHelpers::SlotData<void(TrayPlugin *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setVirtualKBVisible'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setUserSwitchEnable'
        QtMocHelpers::SlotData<void(const bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setSessionSwitchEnable'
        QtMocHelpers::SlotData<void(const bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'chooseToSession'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'leftKeySwitch'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rightKeySwitch'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setKBLayoutVisible'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setKeyboardType'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'setKeyboardList'
        QtMocHelpers::SlotData<void(const QStringList &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 31 },
        }}),
        // Slot 'onItemClicked'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'updateModuleVisible'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCanShowMenu'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'updatePluginVisible'
        QtMocHelpers::SlotData<void(const QString, bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Bool, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ControlWidget, qt_meta_tag_ZN13ControlWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ControlWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ControlWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ControlWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ControlWidgetE_t>.metaTypes,
    nullptr
} };

void ControlWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ControlWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestSwitchUser(); break;
        case 1: _t->requestShutdown(); break;
        case 2: _t->requestSwitchSession(); break;
        case 3: _t->requestSwitchVirtualKB(); break;
        case 4: _t->requestKeyboardLayout((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 5: _t->requestShowModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->requestShowModule((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->requestShowTrayModule((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->requestShowTrayModule((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 9: _t->notifyKeyboardLayoutHidden(); break;
        case 10: _t->addModule((*reinterpret_cast<std::add_pointer_t<TrayPlugin*>>(_a[1]))); break;
        case 11: _t->removeModule((*reinterpret_cast<std::add_pointer_t<TrayPlugin*>>(_a[1]))); break;
        case 12: _t->setVirtualKBVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setUserSwitchEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setSessionSwitchEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->chooseToSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->leftKeySwitch(); break;
        case 17: _t->rightKeySwitch(); break;
        case 18: _t->setKBLayoutVisible(); break;
        case 19: _t->setKeyboardType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->setKeyboardList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 21: _t->onItemClicked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->updateModuleVisible(); break;
        case 23: _t->setCanShowMenu((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->updatePluginVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TrayPlugin* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TrayPlugin* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)()>(_a, &ControlWidget::requestSwitchUser, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)()>(_a, &ControlWidget::requestShutdown, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)()>(_a, &ControlWidget::requestSwitchSession, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)()>(_a, &ControlWidget::requestSwitchVirtualKB, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)(const QPoint & )>(_a, &ControlWidget::requestKeyboardLayout, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)(const QString & , const bool )>(_a, &ControlWidget::requestShowModule, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)(QWidget * , QWidget * , const bool )>(_a, &ControlWidget::requestShowTrayModule, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControlWidget::*)()>(_a, &ControlWidget::notifyKeyboardLayoutHidden, 9))
            return;
    }
}

const QMetaObject *ControlWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ControlWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ControlWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ControlWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void ControlWidget::requestSwitchUser()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ControlWidget::requestShutdown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ControlWidget::requestSwitchSession()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ControlWidget::requestSwitchVirtualKB()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ControlWidget::requestKeyboardLayout(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ControlWidget::requestShowModule(const QString & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 7
void ControlWidget::requestShowTrayModule(QWidget * _t1, QWidget * _t2, const bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void ControlWidget::notifyKeyboardLayoutHidden()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
